﻿using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Linq;
using System.Text;
using System.Windows.Forms;
using Microsoft.PointOfService;
using Microsoft.Win32;
using System.Collections;
namespace AWTX_Scales
{
   public partial class ZP900POSNET : Form
   {
      private PosExplorer posExplorer; //Explorer to find all POS devices, and handle plug and play events.
      private Scale scaleServiceObject;   //Our scale service object.

      public ZP900POSNET()
      {
         InitializeComponent();
      }


      /// <summary>
      /// Creates pos explorer, and registers events. Activates ZP900Scale if plugged in already.
      /// </summary>
      /// <param name="sender"></param>
      /// <param name="e"></param>
      private void Form1_Load(object sender, EventArgs e)
      {
         UpdateControls();
         try
         {
            //Create PosExplorer to get pos devices along with see plug and play events.
            posExplorer = new PosExplorer(this);

            //Register events for plug and play.
            posExplorer.DeviceAddedEvent += new DeviceChangedEventHandler(posExplorer_DeviceAddedEvent);
            posExplorer.DeviceRemovedEvent += new DeviceChangedEventHandler(posExplorer_DeviceRemovedEvent);

            //Grab all scales that are hooked up.
            ArrayList scaleList;
            scaleList = new ArrayList(posExplorer.GetDevices("Scale"));
            
            //Iterate through all the scales.
            foreach (DeviceInfo di in scaleList)
            {
               //If we find out ZP900 activate it.
               if (di.ServiceObjectName == "ZP900Scale")
               {
                  ActivateScale(di);
                  break;
               }
            }

         }
         catch (Exception ex)
         {
            MessageBox.Show(ex.Message, "Exception Thrown");
         }
      }

      /// <summary>
      /// Fires when a supported plug and play POS device is unplugged. Deactivates passed device if its a ZP900Scale.
      /// </summary>
      /// <param name="sender"></param>
      /// <param name="e"></param>
      void posExplorer_DeviceRemovedEvent(object sender, DeviceChangedEventArgs e)
      {
         //If its scale type and its name is ZP900Scale
         if (e.Device.Type == DeviceType.Scale && e.Device.ServiceObjectName == "ZP900Scale")
         {
            DeactivateScale();
         }
      }

      /// <summary>
      /// Fires when a supported plug and play POS device is plugged in. Acivates passed device if its a ZP900Scale.
      /// </summary>
      /// <param name="sender"></param>
      /// <param name="e"></param>
      void posExplorer_DeviceAddedEvent(object sender, DeviceChangedEventArgs e)
      {
         //If its scale type and its name is ZP900Scale
         if (e.Device.Type == DeviceType.Scale && scaleServiceObject == null && e.Device.ServiceObjectName == "ZP900Scale")
         {
            ActivateScale(e.Device);
         }
      }

      /// <summary>
      /// Activate passed device.
      /// </summary>
      /// <param name="di">Device to be activated.</param>
      private void ActivateScale(DeviceInfo di)
      {
         if (di != null && !di.IsDeviceInfoOf(scaleServiceObject))
         {
            DeactivateScale();

            try
            {
               //Create an instance of our scale and open it up for use.
               scaleServiceObject = (Scale)posExplorer.CreateInstance(di);
               scaleServiceObject.Open();
               UpdateControls();

            }
            catch (Exception ex)
            {
               scaleServiceObject = null;
               MessageBox.Show(ex.Message, "Exception Thrown");
            }
         }
      }

      /// <summary>
      /// Close and set our service object to null.
      /// </summary>
      private void DeactivateScale()
      {
         if (scaleServiceObject != null)
         {
            try
            {
               scaleServiceObject.Close();
            }
            catch (Exception ex)
            {
               MessageBox.Show(ex.Message, "Exception Thrown");
            }
            finally
            {
               scaleServiceObject = null;
               UpdateControls();
            }
         }

      }

      /// <summary>
      /// Controls what controls should be displayed on our form and their text.
      /// </summary>
      private void UpdateControls()
      {
         if (scaleServiceObject != null)
         {
            statusLbl.Text = "Connected";
            weightLbl.Visible = true;
            getWeightLbl.Visible = true;
            zeroBtn.Visible = true;
            getWeightBtn.Visible = true;
            getMaxWeightLbl.Visible = true;
            maxWeightBtn.Visible = true;
            maxWeightLbl.Visible = true;
            getWeightUnitLbl.Visible = true;
            weightUnitBtn.Visible = true;
            weightUnitLbl.Visible = true;
            claimBtn.Visible = true;
            releaseBtn.Visible = true;
         }
         else
         {
            statusLbl.Text = "Disconnected";
            weightLbl.Visible = false;
            getWeightLbl.Visible = false;
            getWeightLbl.Text = "Request Weight";
            zeroBtn.Visible = false;
            getWeightBtn.Visible = false;
            getMaxWeightLbl.Visible = false;
            getMaxWeightLbl.Text = "Request Max Weight";
            maxWeightBtn.Visible = false;
            maxWeightLbl.Visible = false;
            getWeightUnitLbl.Text = "Request Weight Unit";
            getWeightUnitLbl.Visible = false;
            weightUnitBtn.Visible = false;
            weightUnitLbl.Visible = false;
            claimBtn.Visible = false;
            releaseBtn.Visible = false;
         }
      }

      /// <summary>
      /// Handle Get Weight Button Press.
      /// </summary>
      /// <param name="sender"></param>
      /// <param name="e"></param>
      private void getWeightBtn_Click(object sender, EventArgs e)
      {
         try
         { 
            getWeightLbl.Text = scaleServiceObject.ReadWeight(0).ToString();
         }
         catch (Exception ex)
         {
            MessageBox.Show(ex.Message, "Exception Thrown");
         }
      }

      /// <summary>
      /// Handle Zero Button Click.
      /// </summary>
      /// <param name="sender"></param>
      /// <param name="e"></param>
      private void zeroBtn_Click(object sender, EventArgs e)
      {
         try
         {
            scaleServiceObject.ZeroScale();
         }
         catch (Exception ex)
         {
            MessageBox.Show(ex.Message, "Exception Thrown");
         }
      }

      /// <summary>
      /// Handle Max Weight Button Press.
      /// </summary>
      /// <param name="sender"></param>
      /// <param name="e"></param>
      private void maxWeightBtn_Click(object sender, EventArgs e)
      {
         try
         {
            getMaxWeightLbl.Text = scaleServiceObject.MaximumWeight.ToString();
         }
         catch (Exception ex)
         {
            MessageBox.Show(ex.Message, "Exception Thrown");
         }
      }

      /// <summary>
      /// Handle Weight Unit Button Press.
      /// </summary>
      /// <param name="sender"></param>
      /// <param name="e"></param>
      private void weightUnitBtn_Click(object sender, EventArgs e)
      {
         try 
         { 
            if (scaleServiceObject.WeightUnit == WeightUnit.Pound)
            {
               getWeightUnitLbl.Text = "Pounds";
            }
            else
            {
               getWeightUnitLbl.Text = "KG";
            }
         }
         catch (Exception ex)
         {
            MessageBox.Show(ex.Message, "Exception Thrown");
         }
      }

      private void releaseBtn_Click(object sender, EventArgs e)
      {
         try
         {
            scaleServiceObject.Release();
            scaleServiceObject.DeviceEnabled = false;
         }
         catch (Exception ex)
         {
            MessageBox.Show(ex.Message, "Exception Thrown");
         }
      }

      private void claimBtn_Click(object sender, EventArgs e)
      {
         try
         {
            scaleServiceObject.Claim(0);
            scaleServiceObject.DeviceEnabled = true;
         }
         catch (Exception ex)
         {
            MessageBox.Show(ex.Message, "Exception Thrown");
         }
      }

 
        private void helpToolStripMenuItem_Click(object sender, EventArgs e)
        {
            frmAbout about = new frmAbout();
            about.AboutProductName = "ZP900 POS.NET Test Harness";
            about.AboutPartNumber = "AWT30-500197";
            about.AboutVersionNumber = "Version 0.0.0.02";
            about.AboutDescription = "This is a sample application that shows how to interface with the ZP900 Pos.Net scale driver.";
            about.AboutSerialNumber = "0001";
            about.AboutCompanyName = "Avery Weigh-Tronix";

            about.ShowDialog();


        }
   }
}
